@@ -83,7 +83,7 @@ def import_torch_dataset(name, dataset, classes, state):
             )
         chan_to_bytes = lambda chan: [bytes(row) for row in chan]
         im_to_bytes = lambda im: list(map(chan_to_bytes, im))
-        im_as_list = image.numpy().astype(np.uint8).tolist()
+        im_as_list = image.numpy().astype(numpy.uint8).tolist()
         im_activations = list(map(lambda x: x[i, :].tolist(), state))
         imageList.append(
             ImageFile(
